Troubleshooting
===============

IP address unknown
------------------

If you have a DHCP server set up in your network, the QiController will
automatically request a dynamic IP address appropriate to your network. In this
case you can either look the address up at the DHCP server or use the MAC
address of the QiController to perform a reverse lookup in your subnet.

If your network depends on static IP addresses, this is also possible although
more complex. In this case, please contact a developer. We will then configure
the system for you with a fixed IP address that you can use afterwards.
